<?php

/**
 * Redirect form callback.
 *
 * Processes any information and redirects to main settings page.
 */
function hubspot_api_oauth_redirect($form, &$form_state) {
  if (isset($_GET['code'])) {
    global $base_url;

    $options = [
      'method' => 'POST',
      'data' => http_build_query(
        [
          'grant_type' => 'authorization_code',
          'client_id' => variable_get('hubspot_api_client_id', ''),
          'client_secret' => variable_get('hubspot_api_client_secret'),
          'redirect_uri' => $base_url . '/admin/config/services/hubspot/redirect',
          'code' => $_GET['code'],
        ]
      ),
    ];
    $response = drupal_http_request(HUBSPOT_API_URL . HUBSPOT_API_REFRESH_TOKEN_ENDPOINT, $options);
    $errors = hubspot_api_validate_response($response);
    if (is_array($errors) && !empty($errors)) {
      // Display any errors that may have occurred.
      foreach ($errors as $error) {
        watchdog('hubspot_api', 'Failed to get OAuth access token: %error', ['%error' => $error], 'error');
      }
    }
    else {
      $response_data = json_decode($response->data);
      // Save any Access/Refresh Tokens that may have been returned.
      $access_token = $response_data->access_token;
      $refresh_token = $response_data->refresh_token;
      $expires_in = $response_data->expires_in;
      $time = REQUEST_TIME;

      variable_set('hubspot_api_access_token', $access_token);
      variable_set('hubspot_api_refresh_token', $refresh_token);
      variable_set('hubspot_api_expire_date', $expires_in + $time);
    }
  }
  else {
    if ($_GET['error'] == 'access_denied') {
      // Show error message if access was denied.
      drupal_set_message(t('Access was denied to HubSpot API.'), 'error');
    }
  }

  drupal_goto('admin/config/services/hubspot');

  return $form;
}
